# Table of Contents

- [erp-transformation-foundation](<./erp-transformation-foundation.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Phase 0. Foundation: Transformation Strategy and Setup](<./Phase-0.-Foundation-Transformation-Strategy-and-Setup.md>)
  - [Overview](<./Phase-0.-Foundation-Transformation-Strategy-and-Setup/Overview.md>)
  - [The Contribution of Enterprise Architects to Phase 0](<./Phase-0.-Foundation-Transformation-Strategy-and-Setup/The-Contribution-of-Enterprise-Architects-to-Phase-0.md>)
  - [Define the Role of EA for the Subsequent Phases of the ERP Transformation](<./Phase-0.-Foundation-Transformation-Strategy-and-Setup/Define-the-Role-of-EA-for-the-Subsequent-Phases-of-the-ERP-Transformation.md>)
